# Changelog

## [0.0.36a10](https://github.com/OpenVoiceOS/ovos-utils/tree/0.0.36a10) (2023-10-19)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.36a9...0.0.36a10)

**Fixed bugs:**

- fix/scheduled\_event message.context [\#196](https://github.com/OpenVoiceOS/ovos-utils/pull/196) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.36a9](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.36a9) (2023-10-12)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.36a8...V0.0.36a9)

**Implemented enhancements:**

- update FakeBus to support session [\#195](https://github.com/OpenVoiceOS/ovos-utils/pull/195) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.36a8](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.36a8) (2023-09-26)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.36a7...V0.0.36a8)

**Implemented enhancements:**

- Support "logging" section to allow per-service log level changes [\#189](https://github.com/OpenVoiceOS/ovos-utils/pull/189) ([lbt](https://github.com/lbt))

## [V0.0.36a7](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.36a7) (2023-09-17)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.36a6...V0.0.36a7)

**Fixed bugs:**

- hotfix/gui\_sync [\#192](https://github.com/OpenVoiceOS/ovos-utils/pull/192) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.36a6](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.36a6) (2023-09-13)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.36a5...V0.0.36a6)

**Merged pull requests:**

- refactor/less\_gui\_spam [\#191](https://github.com/OpenVoiceOS/ovos-utils/pull/191) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.36a5](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.36a5) (2023-09-05)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.36a4...V0.0.36a5)

**Implemented enhancements:**

- Only scan for executables if a good one has not yet been found [\#187](https://github.com/OpenVoiceOS/ovos-utils/pull/187) ([lbt](https://github.com/lbt))

## [V0.0.36a4](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.36a4) (2023-09-05)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.36a3...V0.0.36a4)

**Implemented enhancements:**

- IntentServiceInterface Tests and Minor Fixes [\#186](https://github.com/OpenVoiceOS/ovos-utils/pull/186) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.36a3](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.36a3) (2023-08-17)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.36a2...V0.0.36a3)

**Fixed bugs:**

- remove \_HACK [\#184](https://github.com/OpenVoiceOS/ovos-utils/pull/184) ([JarbasAl](https://github.com/JarbasAl))

**Closed issues:**

- \_\_HACK\_preload in file\_utils.py causes circular import when launching ovos\_dinkum\_listener [\#183](https://github.com/OpenVoiceOS/ovos-utils/issues/183)

## [V0.0.36a2](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.36a2) (2023-08-07)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.36a1...V0.0.36a2)

**Fixed bugs:**

- HACK / speed up resolve\_ovos\_resource\_file [\#182](https://github.com/OpenVoiceOS/ovos-utils/pull/182) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.36a1](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.36a1) (2023-08-07)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.35...V0.0.36a1)

**Merged pull requests:**

- Update `events` module docs and default values [\#181](https://github.com/OpenVoiceOS/ovos-utils/pull/181) ([NeonDaniel](https://github.com/NeonDaniel))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
